onAlignedAudioAuxData method
Aligned audio aux frames callback.
Available: Since 2.22.0
Description: In this callback, you can receive the audio aux frames which aligned with accompany. Developers can record locally.
When to trigger: This callback function will not be triggered until enableAlignedAudioAuxData is called to turn on the function and startPublishingStream or startRecordingCapturedData is called.
Restrictions: To obtain audio aux data of the media player from this callback, developers need to call enableAux and start of MediaPlayer.
Caution: This callback is a high-frequency callback, please do not perform time-consuming operations in this callback, and the data in this callback cannot be modified.
dataAudio data in PCM format.paramParameters of the audio frame.
Implementation
void onAlignedAudioAuxData(
Uint8List data,
ZegoAudioFrameParam param,
) {}