onAudioDeviceStateChanged method
void
onAudioDeviceStateChanged(
- ZegoUpdateType updateType,
- ZegoAudioDeviceType deviceType,
- ZegoDeviceInfo deviceInfo
The callback triggered when there is a change to audio devices (i.e. new device added or existing device deleted).
Only supports desktop. This callback is triggered when an audio device is added or removed from the system. By listening to this callback, users can update the sound collection or output using a specific device when necessary.
updateTypeUpdate type (add/delete)deviceTypeAudio device typedeviceInfoAudio device information
Implementation
void onAudioDeviceStateChanged(
ZegoUpdateType updateType,
ZegoAudioDeviceType deviceType,
ZegoDeviceInfo deviceInfo,
) {}