onCapturedSoundLevelInfoUpdate method
void
onCapturedSoundLevelInfoUpdate(
- ZegoSoundLevelInfo soundLevelInfo
The local captured audio sound level callback, supported vad.
Available since: 2.10.0
Description: The local captured audio sound level callback.
Trigger: After you start the sound level monitor by calling startSoundLevelMonitor.
Caution:
- The callback notification period is the parameter value set when the
startSoundLevelMonitoris called. - This callback is a high-frequency callback, and it is recommended not to do complex logic processing inside the callback.
Related APIs: Start sound level monitoring via
startSoundLevelMonitor. Monitoring remote played audio sound level by callback onRemoteSoundLevelUpdate or onRemoteSoundLevelInfoUpdate.
soundLevelInfoLocally captured sound level value, ranging from 0.0 to 100.0.
Implementation
void onCapturedSoundLevelInfoUpdate(
ZegoSoundLevelInfo soundLevelInfo,
) {}