onScreenCaptureSourceRectChanged method
The callback will be triggered when the state of the capture target window change.
Available since: 3.7.0
Caution: The callback does not actually take effect until call setEventHandler to set.
Restrictions: Only available on Windows/macOS.
sourceCallback screen capture source object.captureRectCapture source rect.
Implementation
void onScreenCaptureSourceRectChanged(
ZegoScreenCaptureSource source,
Rect captureRect,
) {}