onMediaPlayerSoundLevelUpdate method
The callback of sound level update.
Description: The callback of sound level update.
Trigger: The callback frequency is specified by EnableSoundLevelMonitor.
Caution: The callback does not actually take effect until call setEventHandler to set.
Related APIs: To monitor this callback, you need to enable it through EnableSoundLevelMonitor.
mediaPlayerCallback player object.soundLevelSound level value, value range:0.0, 100.0.
Implementation
void onMediaPlayerSoundLevelUpdate(
ZegoMediaPlayer mediaPlayer,
double soundLevel,
) {}