ZegoUIKitUserPropertiesNotifier class

Inheritance
Implemented types

Constructors

ZegoUIKitUserPropertiesNotifier(ZegoUIKitUser user, {String? mixerStreamID})

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user ZegoUIKitUser
no setter
value int
The current value of the object.
no setteroverride

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
onCameraMuteModeChanged() → void
onCameraStatusChanged() → void
onInRoomAttributesUpdated() → void
onMicrophoneMuteModeChanged() → void
onMicrophoneStatusChanged() → void
onUserListUpdated(List<ZegoUIKitUser> users) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited